<?php
namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\Controller;
use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DTO\Response\Notification;
use Modules\Cadastros\Services\FilialAtendidaNaoAtendidaPeloFornecedorService;

class FilialAtendidaNaoAtendidaPeloFornecedorController extends \Zeedhi\Framework\Controller\Report{

    protected $connection;
    protected $stNomeRel;
    protected $stExtensao;
    protected $birtStrategy;
    protected $qr2Strategy;

    public function __construct(ReportService $reportService, FilialAtendidaNaoAtendidaPeloFornecedorService $service, $connection, $birtStrategy,$qr2Strategy ) {
        parent::__construct($reportService);
        $this->connection    = $connection;
        $this->service       = $service;
        $this->birtStrategy  = $birtStrategy;
        $this->qr2Strategy   = $qr2Strategy;
    }

    public function saveFilial(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        try {
            $this->service->insertReforfil($row);
            $this->service->updateReforfil($row);

            $this->service->gravaPrazoExpedFil($row);
            $this->service->deletePrazoFornExpedProd($row);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function filialDelete(DTO\Request\Row $request, DTO\Response $response){
        try{
            $row = $request->getRow();

            foreach ($row as $value) {
                if($this->service->verifyFornecedor($value)) {
                    $this->service->deleteReforfil($value);
                } else {
                    $response->setError(new Response\Error("REGIAO_N_ATENDIDA_FORN", 500));
                }
            }
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }

    public function exportFilial(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        try {

            if($row['CDFIL'] !== 'T') {
                foreach($row['CDFIL'] as $filial) {
                    $row['CDFIL'] = $filial['CDFILIAL'];
                    $this->service->exportReforfil($row);
                }
            } else {
                $this->service->exportReforfil($row);
            }
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }

    protected $reportMapping = array ();

    public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();

        $this->stNomeRel = $this->getReportName($row);

        $row['NRINSJURFORNINI1']     =  $row['NRINSJURFORNINI'];
        $row['NRINSJURFORNFIN1']     =  $row['NRINSJURFORNFIN'];
        $row['CDFORNECEDINI1']       =  $row['CDFORNECEDINI'];
        $row['CDFORNECEDFIN1']       =  $row['CDFORNECEDFIN'];
        $row['NMRAZSOCFORNINI1']     =  $row['NMRAZSOCFORNINI'];
        $row['NMRAZSOCFORNFIN1']     =  $row['NMRAZSOCFORNFIN'];
        $row['IDTPIJURFORNINI1']     =  $row['IDTPIJURFORNINI'];
        $row['IDTPIJURFORNFIN1']     =  $row['IDTPIJURFORNFIN'];
        $row['NRORG1']               =  $row['NRORG'];


        $tipoRelatorio = $row['STRATEGY'];

        if($tipoRelatorio == 'BIRT'){
            $paramRelatorio = array(
                "NRINSJURFORNINI"  => "P_NRINSJURFORNINI",
                "NRINSJURFORNFIN"  => "P_NRINSJURFORNFIN",
                "NRINSJURFORNINI1"  => "P_NRINSJURFORNINI1",
                "NRINSJURFORNFIN1"  => "P_NRINSJURFORNFIN1",
                "NMRAZSOCFORNINI"  => "P_NMRAZSOCFORNINI",
                "NMRAZSOCFORNFIN"  => "P_NMRAZSOCFORNFIN",
                "NMRAZSOCFORNINI1"  => "P_NMRAZSOCFORNINI1",
                "NMRAZSOCFORNFIN1"  => "P_NMRAZSOCFORNFIN1",
                "IDTPIJURFORNINI"  => "P_IDTPIJURFORNINI",
                "IDTPIJURFORNFIN"  => "P_IDTPIJURFORNFIN",
                "IDTPIJURFORNINI1"  => "P_IDTPIJURFORNINI1",
                "IDTPIJURFORNFIN1"  => "P_IDTPIJURFORNFIN1",
                "NRORG"            => "P_NRORG",
                "NRORG1"            => "P_NRORG1",
                "CDFORNECEDINI"    => "P_CDFORNECEDINI",
                "CDFORNECEDINI1"    => "P_CDFORNECEDINI1",
                "CDFORNECEDFIN"    => "P_CDFORNECEDFIN",
                "CDFORNECEDFIN1"    => "P_CDFORNECEDFIN1"
            );

        }else {
            $paramRelatorio = array(

               "NRINSJURFORNFIN" => "P_INFIM",
               "NRINSJURFORNINI" => "P_ININI",
               "NMRAZSOCFORNFIN" => "P_NMFIM",
               "NMRAZSOCFORNINI" => "P_NMINI",
               "IDTPIJURFORNFIN" => "P_TPFIM",
               "IDTPIJURFORNINI" => "P_TPINI",
                "NRINSJURFORNINI1" => "P_CDINI",
               "NRINSJURFORNFIN1" => "P_CDFIM",
            );


        }

        $qr2type = isset($row['QR2TYPE']) ? $row['QR2TYPE'] : 'PDF';
        $this->birtStrategy->setReportFormat($qr2type);
        $this->qr2Strategy->setQr2Type($qr2type);

        $this->reportMapping[$this->stNomeRel] = array(
            'strategy' => $tipoRelatorio,
            'parameterMapping' => $paramRelatorio
        );
    }

    public function saveFornecedorEdit(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        try {
            $this->service->saveFornecedor($row);
        } catch(\Exception $e){
            $response->setError(new Error($e->getMessage(), 1));
        }
    }

    public function saveEditUni(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        try {
            if(isset($row['CDPERIENTR']) && !empty($row['CDPERIENTR'])){
                $this->service->insertReforfil($row);
                $this->service->updateReforfil($row);
            } else {
                $this->service->deleteReforfil($row);
            }

            $this->service->gravaPrazoExpedFil($row);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function saveEditExpedicaoProduto(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        try {
            $this->service->updatePrazoFornExpedProd($row);
            $this->service->insertPrazoFornExpedProd($row);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteExpProd(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();

        try {
            $this->service->deletePrazoFornExpedProd($row);

        } catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
}