<?php

namespace Modules\Cotacao\Modules\Pedido\Controllers;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Request\Filter;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Util\SupUtilities;

class ControlePedidoColeta extends \Teknisa\GER\Controllers\TeknisaCrud
{

    protected $crudService;
    protected $service;
    protected $controlePedidoColetaAceite;
    protected $dataSourceManager;
    protected $smtpUtil;
    protected $entityManager;
    protected $zhFileUploader;
    protected $fileServerURL;
    protected $supUtilities;
    protected $dataSourceName;

    public function __construct($crudService, $parameterBag, $service, $controlePedidoColetaAceite, $dataSourceManager, $smtpUtil, EntityManager $entityManager, $zhFileUploader, $fileServerURL, SupUtilities $supUtilities)
    {
        parent::__construct($crudService, $parameterBag);
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->service = $service;
        $this->controlePedidoColetaAceite = $controlePedidoColetaAceite;
        $this->dataSourceManager = $dataSourceManager;
        $this->smtpUtil = $smtpUtil;
        $this->entityManager = $entityManager;
        $this->templatesDir = realpath(__DIR__ . '/../../../../../Util/Template');
        $this->zhFileUploader    = $zhFileUploader;
        $this->fileServerURL     = $fileServerURL;
        $this->supUtilities = $supUtilities;
    }

    public function gridControlePedidoColeta(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            array_push($conditions, [
                'columnName' => 'CDFILIAL',
                'value' =>  $this->service->getCdFilial(),
                'operator' => '=',
            ]);
            $pedidos = $this->crudService->getFilteredDataSet("gridControlePedidoColeta", $conditions)->getRows();
            $parents = array();

            foreach ($pedidos as &$pedido) {
                unset($pedido["ID"]);
                if (!isset($parents[$pedido['NRPEDGRID']])) {
                    $parents[$pedido['NRPEDGRID']] = array(
                        'ID'                => $pedido['NRPEDGRID'],
                        'INSCRICAO'         => $pedido['NRINSJURFORN'],
                        'NRINSJURFORN'      => $pedido['QTDEFORN'] == 1 ? $pedido['NRINSJURFORN'] : '',
                        'FORNECEDOR'        => $pedido['NMFANTFORN'],
                        'NMFANTFORN'        => $pedido['QTDEFORN'] == 1 ? $pedido['NMFANTFORN'] : '',
                        'NMRAZSOCFORN'      => $pedido['NMRAZSOCFORN'],
                        'IDTPIJURFORN'      => $pedido['IDTPIJURFORN'],
                        'SITUACAO'          => $pedido['IDSITUPEDCOLETA'],
                        'OPERACEITE'        => $pedido['OPERACEITE'],
                        'NRPEDGRID'         => $pedido['NRPEDGRID'],
                        'NRPEDIDOCOL'       => $pedido['NRPEDIDOCOL'],
                        'NRPEDCOLETA'       => $pedido['NRPEDCOLETA'],
                        'CDFORNECED'        => $pedido['CDFORNECED'],
                        'COMPRADOR'         => $pedido['COMPRADOR'],
                        'CDFILIAL'          => $pedido['CDFILIAL'],
                        'REGIAO'            => $pedido['NMREGIAO'],
                        'CDOPERLANC'        => $pedido['CDOPERLANC'],
                        'IDRENEGOCIAPCOL'   => $pedido['IDRENEGOCIAPCOL'],
                        'IDSITUCOLETAGERAL' => $pedido['IDSITUCOLETAGERAL'],
                        'IDSITUPEDCOL'      => $pedido['IDSITUPEDCOL'],
                        'DTEXPIRAPEDCOL'    => $pedido['DTEXPIRAPEDCOL'],
                        'DTINIPERGERAL'     => $pedido['DTINIPERGERAL'],
                        'DTFINPERGERAL'     => $pedido['DTFINPERGERAL'],
                        'DTINIPERCOT'       => $pedido['DTINIPERCOT'],
                        'DTFINPERCOT'       => $pedido['DTFINPERCOT'],
                        'DTVALIDADE'        => $pedido['DTINIPERGERAL'] . ' - ' . $pedido['DTFINPERGERAL'],
                        'DTPEDCOLETA'       => $pedido['DTPEDCOLETA'],
                        'EXISTS_ITEMCOLE'   => $pedido['EXISTS_ITEMCOLE'],
                        'IDSISDOS'          => $pedido['IDSISDOS'],
                        'CDFILCENTCMP'      => $pedido['CDFILCENTCMP'],
                        'IDUTSTATUSLISPR'   => $pedido['IDUTSTATUSLISPR'],
                        'CDOPERADOR'        => $pedido['CDOPERADOR'],
                        'IDUTLCTRLTERMO'    => $pedido['IDUTLCTRLTERMO'],
                        'QTDEFORN'          => $pedido['QTDEFORN'],
                        'IDUTLPROCMP'       => $pedido['IDUTLPROCMP'],
                    );
                }
                $pedido['PARENT'] = $parents[$pedido['NRPEDGRID']]['ID'];
            };

            foreach ($parents as &$parentRow) {
                $filteredData = array_filter($pedidos, function ($row) use ($parentRow) {
                    return $row['NRPEDIDOCOL'] === $parentRow['ID'];
                });

                $pedColeta = implode('_', array_map(function ($row) {
                    return $row['NRPEDCOLETA'];
                }, $filteredData));

                $parentRow['NRPEDCOLETA'] = $pedColeta;
            }

            $dataset = array_merge(array_values($parents), array_values($pedidos));

            $response->addDataSet(new DataSet("pedidos", $dataset));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    private function buildTotals($pedidos)
    {
        $idSisDos = $this->service->getIdSisDos();
        foreach ($pedidos as &$pedido) {

            if (($idSisDos === '3') && ($pedido['VRPRECREN'] == 0)) {
                $pedido['VRPRECREN'] = $pedido['VRPRECUNIT'];
            }

            $pedido['TOTALANT']     = $pedido['VRPRECUNITANT']    * $pedido['QUANTIDADE'];
            $pedido['TOTALATUAL']   = $pedido['VRPRECUNIT']       * $pedido['QUANTIDADE'];
            $pedido['VLRTOTALOBJ']  = $pedido['VRPRECOOBJETIVO']  * $pedido['QUANTIDADE'];
            $pedido['VLRTOTALRET']  = $pedido['VRPRECREN']        * $pedido['QUANTIDADE'];

            if ($pedido['VRPRECUNITANT'] == 0) {
                $pedido['VARCOTACAO']   = 0;
                $pedido['VARRENEGOCIA'] = 0;
                $pedido['VAROBJETIVO']  = 0;
            } else {
                $pedido['VARCOTACAO']   = (($pedido['VRPRECUNIT']       - $pedido['VRPRECUNITANT']) / ($pedido['VRPRECUNITANT'])) * 100;
                $pedido['VARRENEGOCIA'] = (($pedido['VRPRECREN']       - $pedido['VRPRECUNITANT']) / ($pedido['VRPRECUNITANT'])) * 100;
                $pedido['VAROBJETIVO']  = (($pedido['VRPRECOOBJETIVO'] - $pedido['VRPRECUNITANT']) / ($pedido['VRPRECUNITANT'])) * 100;
            }
        }

        return $pedidos;
    }

    public function gridItempedcol(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $conditions = $request->getFilterCriteria()->getConditions();
            $itensPedido = $this->crudService->getFilteredDataSet("gridItempedcol", $conditions)->getRows();
            $itemsWithTotals = $this->buildTotals($itensPedido);
            $response->addDataSet(new DataSet("gridItempedcol", $itemsWithTotals));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function negociacao(DTO\Request\Filter $request, DTO\Response $response)
    {
        $this->dataSourceName = "graficoNegociacao";
        $this->parameterBagColumns = array('CDFILIAL', 'NRPEDIDOCOL', 'DTINIVALPCOL', 'DTFINVALPCOL', 'CDPRODUTO', 'CDMARCA');

        $this->find($request, $response);
    }

    public function saveProduto(DTO\Request $request, DTO\Response $response)
    {
        $produtos = $request->getRow();

        try {
            $this->service->iniciaTransacao();

            foreach ($produtos as $produto) {
                if ($produto['VRPRECOOBJETIVO'] > 0) {
                    $produto['IDITPEDPRIONEG'] = 'S';

                    $this->service->atualizaPrecObj($produto);
                    $this->service->atualizaPrecObjItmPedCol($produto);
                    $this->service->preencheGrafico($produto);
                }
            }

            $this->service->flush();
            $this->service->commit();
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function updateSituacao(DTO\Request $request, DTO\Response $response)
    {
        $pedidos = $request->getRow();
        try {
            $this->service->iniciaTransacao();

            foreach ($pedidos['PEDIDOS'] as $pedido) {
                $this->service->atualizaSituPedcolgeral($pedido, $pedidos['DTEXPIRAPEDCOL']);
                $this->service->atualizaSituPedcoleta($pedido);
            }
            $this->service->flush();
            $this->service->commit();
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function verificaInconsistenciaGeraCot(&$pedidosPai, $pedidosFilho)
    {
        try {
            foreach ($pedidosPai as &$pedido) {
                $nrpedido = $pedido['NRPEDGRID'];
                $code = $this->service->ACEITA_PEDCOTWEB($pedido['CDFILIAL'], $nrpedido, 'S');
                $pedido['IDACEITEOK'] = $code['P_IDACEITEOK'];

                if ($pedido['IDACEITEOK'] === 'ERRO') {
                    $data = array_filter($pedidosFilho, function ($row) use ($nrpedido) {
                        return $row['NRPEDGRID'] === $nrpedido;
                    });
                    foreach ($data as $row) {
                        $this->service->alteraStatus($row, 'inconsistencia');
                    }
                }
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function getLogngerapedweb($row)
    {
        $dataSourceName = 'logngerapedweb';
        $conditions = array(
            array(
                'columnName' => 'CDFILNGERPEDWEB',
                'operator' => '=',
                "value" => $row['CDFILIAL']
            ),
            array(
                'columnName' => 'NRPEDNGERPEDWEB',
                'operator' => '=',
                "value" => $row['NRPEDIDOCOL']
            )
        );

        return $this->crudService->getFilteredDataSet($dataSourceName, $conditions)->getRows();
    }

    public function geraCotacaoWeb(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $mensagem = 'N';
        $inconsistencias = array();
        $code = 1;
        $erroVerificaIncGeraCot = false;

        try {
            $aceite = array();

            if (!$row['FINALIZEINCONSIST']) {
                $this->verificaInconsistenciaGeraCot($row['PEDIDOSPAI'], $row['PEDIDOS']);

                if (!$row['FINALIZEPROCESSACEITE']) {
                    $this->controlePedidoColetaAceite->verifyParamTermoAceite($row['FILIAL_LOGADA'], $row['PEDIDOS'], $row['NMOPERADORLOGADO'], $row['EMAILLOGADO'], $row['PEDIDOSPAI']);
                }
            }

            $resultPedidos = array();

            foreach ($row['PEDIDOSPAI'] as &$pedidoPai) {
                if (isset($pedidoPai['IDACEITEOK']) && $pedidoPai['IDACEITEOK'] === 'ERRO') {
                    $inconsistencias = array_merge($inconsistencias, $this->getLogngerapedweb($pedidoPai));
                } else {
                    if (!isset($pedidoPai['ACEITE']) || (isset($pedidoPai['ACEITE']) && $pedidoPai['ACEITE'] != 'AGUARD_ACEITE_FORN')) {
                        $pedidos = array_filter($row['PEDIDOS'], function ($row) use ($pedidoPai) {
                            return $row['NRPEDIDOCOL'] == $pedidoPai['NRPEDIDOCOL'];
                        });

                        foreach ($pedidos as &$pedido) {
                            if ($pedido['IDUTSTATUSLISPR'] === 'S' && $row['LISTAPREC'] === 'S') {
                                $listas = $this->service->existeListaPreco($pedido);
                                if (isset($listas) && count($listas)) {
                                    foreach ($listas as $lista) {
                                        $pedido['MESSAGE'] = $this->service->verificaListaPrecoDefinitiva($lista, $pedido);
                                    }
                                }
                            }

                            $retorno = $this->service->geraCotacao($pedido, $row);
                            $pedido['COTA_N_GER'] = $retorno['P_COTA_N_GER'];
                        }

                        $gerouCotacao = array_filter($pedidos, function ($row) {
                            return $row['COTA_N_GER'] === 'N';
                        });

                        if ($row['FINALIZEPROCESSACEITE'] && count($gerouCotacao)) {
                            $this->controlePedidoColetaAceite->enviaEmailComprador($row, $pedidoPai);
                        }

                        $resultPedidos = array_merge($resultPedidos, $pedidos);
                    }
                }
            }

            $response->addDataSet(new DataSet('data', ['PEDIDOSPAI' => $row['PEDIDOSPAI'], 'PEDIDOS' => $resultPedidos, 'INCONSITENCIAS' => $inconsistencias]));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function enviaEmailFornecedor(DTO\Request $request, DTO\Response $response)
    {
        $email = $request->getRow();
        $result = [
            'SUCCESS' => [],
            'FAIL'    => []
        ];

        try {
            if (\Zeedhi\Framework\Util\Functions::arrayKeyExists('PEDIDOS', $email) && count($email['PEDIDOS']) != 0) {
                foreach ($email['PEDIDOS'] as $pedido) {
                    try {
                        $messageSendMail = $this->supUtilities->messageSendMail($this->service->getCdFilial(), $email['ASSUNTO'], $pedido['MENSAGEM'], 'PORTAL E-COMMERCE');
                        $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$pedido['CDFORNECED']]);
                        $this->supUtilities->enviaEmail(false, $email['ASSUNTO'], false, $messageSendMail, $emailFornecedor);
                        $result['SUCCESS'] = $email['DADOSPEDIDO'];
                        $response->addDataSet(new DataSet('data', $result));
                    } catch (\Exception $e) {
                        $email['DADOSPEDIDO'][0]['ERROR'] = $e->getMessage();
                        $result['FAIL'] = $email['DADOSPEDIDO'];
                        $response->addDataSet(new DataSet('data', $result));
                    }
                }
            } else if (isset($email['DADOSPEDIDO']) && is_array($email['DADOSPEDIDO']) && count($email['DADOSPEDIDO'])) {
                try {
                    $messageSendMail = $this->supUtilities->messageSendMail($this->service->getCdFilial(), $email['ASSUNTO'], $email['MENSAGEM'], 'PORTAL E-COMMERCE');
                    $emailFornecedor = $this->retornarEmailsFornecedor($email['FORNECEDORES']);
                    $messageSendMail = $this->replaceMnemonicos($messageSendMail, $email['DADOSPEDIDO'][0], $email['URL_PORTAL'], $email['NMOPERADOR']);
                    $this->supUtilities->enviaEmail(false, $email['ASSUNTO'], false, $messageSendMail, $emailFornecedor);
                    $result['SUCCESS'] = $email['DADOSPEDIDO'];
                    $response->addDataSet(new DataSet('data', $result));
                } catch (\Exception $e) {
                    $email['DADOSPEDIDO'][0]['ERROR'] = $e->getMessage();
                    $result['FAIL'] = $email['DADOSPEDIDO'];
                    $response->addDataSet(new DataSet('data', $result));
                }
            }
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    private function replaceMnemonicos($message, $row, $url, $nmOperador)
    {
        $message = str_replace("CNPJ_CPF",     $row['NRINSJURFORN'], $message);
        $message = str_replace("NM_FANTFORN",  $row['NMFANTFORN'],   $message);
        $message = str_replace("NM_RAZSFORN",  $row['NMRAZSOCFORN'], $message);
        $message = str_replace("NR_PEDIDO",    $row['NRPEDIDOCOL'],  $message);
        $message = str_replace("NM_OPERADOR",  $nmOperador,          $message);
        $message = str_replace("URL_PORTAL",   $url,                 $message);
        $message = str_replace("DT_GERACAO",   $row['DTPEDCOLETA'],  $message);
        $message = str_replace("DT_VALIDADE",  $row['DTVALIDADE'],   $message);
        $message = str_replace("DT_EXPIRACAO", $row['DTEXPIRACAO'],  $message);
        return $message;
    }

    private function retornarEmailsFornecedor(array $fornecedores)
    {
        $listaEmails = array();
        $fornecedores = array_unique($fornecedores);
        foreach ($fornecedores as $fornecedor) {
            $emailFornecedores = $this->emailsComRelacaoFornecedor($fornecedor)->getRows()[0];

            if ($emailFornecedores['DSLOGINECO']) {
                $listaEmails = array_merge($listaEmails, explode(',', $emailFornecedores['DSLOGINECO']));
                if ($emailFornecedores['DSEMAILECO']) {
                    $listaEmails = array_merge($listaEmails, explode(',', $emailFornecedores['DSEMAILECO']));
                }
            } else {
            }
        }

        if (!count($listaEmails)) {
            throw new \Exception("E-mail não enviado pois o fornecedor não possui email cadastrado.");
        }

        $listaEmails = array_unique($listaEmails);

        return $listaEmails;
    }

    private function emailsComRelacaoFornecedor($cdforneced)
    {
        $conditions = [
            array(
                "columnName" => "CDFORNECED",
                "operator"   => '=',
                "value"      => $cdforneced
            )
        ];

        return $this->crudService->getFilteredDataSet('emailsRelacionadosFornecedor', $conditions);
    }

    public function retornaMenorMaiorProdutoPedido(DTO\Request $request, DTO\Response $response)
    {
        $pedidos = $request->getRow();
        $menorMaiorProduto = [];

        try {
            $produtos = $this->service->retornaMenorMaiorProdutoPedido($pedidos);
            $qtdeProdutos = count($produtos);

            if ($qtdeProdutos) {
                $menorMaiorProduto = array(
                    "PRODMIN" => $produtos[0]['CDARVPROD'],
                    "NMPRODMIN" => $produtos[0]['NMPRODUTO'],
                    "PRODMAX" => $produtos[$qtdeProdutos - 1]['CDARVPROD'],
                    "NMPRODMAX" => $produtos[$qtdeProdutos - 1]['NMPRODUTO']
                );
            }

            $response->addDataSet(new DataSet("retornaMenorMaiorProdutoPedido", $menorMaiorProduto));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    private function getPrecoObjetivoPedidos($row, $request)
    {
        try {
            if (isset($row['LISTAPEDIDOS']) && isset($row['CONSIDERAMARCA']) && isset($row['PARAMCOMPPRECO'])) {
                if ($row['CONSIDERAMARCA'] === 'S') {
                    if ($row['PARAMCOMPPRECO'] === 'C') {
                        $this->dataSourceName = 'precoObjetivoMarcaEmbalagem';
                    } else {
                        $this->dataSourceName = 'precoObjetivoMarcaEstoque';
                    }
                } else {
                    if ($row['PARAMCOMPPRECO'] === 'C') {
                        $this->dataSourceName = 'precoObjetivoSemMarcaEmbalagem';
                    } else {
                        $this->dataSourceName = 'precoObjetivoSemMarcaEstoque';
                    }
                }

                $nrPedido = join("_", array_unique($row['LISTAPEDIDOS']));

                $filterCriteria = new FilterCriteria($this->dataSourceName);
                $filterCriteria->addCondition('P_PEDIDO', $nrPedido);

                $newRequest = new Filter($filterCriteria, $request->getMethod(), $request->getRoutePath(), $request->getUserId());
                $newResponse = new DTO\Response();

                parent::find($newRequest, $newResponse);
                $data = $newResponse->getDataSets();

                if (is_array($data) && count($data)) {
                    $data = end($data);
                    if ($data->getDataSourceName() === $this->dataSourceName) {
                        return $data->getRows();
                    }
                }
            } else {
                return array();
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function calculaPrecoObjetivo(DTO\Request $request, DTO\Response $response)
    {
        $data = $request->getRow();

        $consideraMarca = $data['CONSIDERAMARCA'];
        $paramCompPreco = $data['PARAMCOMPPRECO'];
        $message        = $data['MESSAGE'];

        try {
            $items = $this->getPrecoObjetivoPedidos($data, $request);

            if (is_array($items) && count($items)) {
                $listaPedidos = join("_", array_unique($data['LISTAPEDIDOS']));

                foreach ($items as $row) {
                    $row['DSOBSRENEGOCIA'] = $message;
                    $this->service->updatePrmarcpedcol($row, $listaPedidos);
                    $this->service->updateMinItempedcol($row, $listaPedidos);
                }

                $response->addDataSet(new DataSet('data', array('NRLISTA' => $listaPedidos, 'ITEMS' => $items)));
            } else {
                $response->addDataSet(new DataSet('data', array('NRLISTA' => '', 'ITEMS' => $items)));
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvaPrecoObjetivoMinimo(DTO\Request $request, DTO\Response $response)
    {
        $data = $request->getRow();

        $listaPedidos = $data['LISTAPEDIDOS'];
        $produtos = $data['PRODUTOS'];

        try {
            $listaPedidos = join("_", array_unique($data['LISTAPEDIDOS']));

            foreach ($produtos as $row) {
                $row['VRPRECUNIPRMARC'] = $row['VRPRECOOBJETIVO'];

                $this->service->updatePrmarcpedcol($row, $listaPedidos);
                $this->service->updateMinItempedcol($row, $listaPedidos);
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), $e->getCode()));
        }
    }

    public function salvarComentario(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        try {
            $data = [];

            array_push($data, [
                'NOTEXISTSPED' => false,
                'COMMENT'      => isset($row['TXCOMENTARIO']) ? $row['TXCOMENTARIO'] : '',
                'NRPEDIDOCOL'  => isset($row['NRPEDIDOCOL']) ? $row['NRPEDIDOCOL'] : '',
                'CDFORNECED'   => isset($row['CDFORNECED']) ? $row['CDFORNECED'] : '',
                'CDFILIAL'     => isset($row['CDFILIAL']) ? $row['CDFILIAL'] : '',
                'fileUpload'   => isset($row['fileUpload']) ? $row['fileUpload'] : ''
            ]);

            $this->service->saveComments($data);
        } catch (Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function sendCommentMail(DTO\Request $request, DTO\Response $response)
    {
        $data = $request->getRow();

        try {
            if (isset($data['DATA'])) {

                foreach ($data['DATA'] as $row) {
                    $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$row['CDFORNECED']]);
                    $messageSendMail = $this->supUtilities->messageSendMail($this->service->getCdFilial(), $row['ASSUNTO'], $row['MENSAGEM'], 'PORTAL E-COMMERCE');
                    $this->supUtilities->enviaEmail($row['EMAIL'], $row['ASSUNTO'], $row['EMAIL'], $messageSendMail, $emailFornecedor);
                }
            }
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function enviaEmailComentario($infoComentario, $row, $response, $rotina)
    {
        try {
            $assunto = 'Comentário - ' . $infoComentario["NRPEDIDOCOL"];
            if ($rotina === 'liberarInconsistencia') {
                $message = $this->service->getMessageInconsistencia($infoComentario);
            } else {
                $message = $this->service->getMessage($infoComentario);
            }
            $messageSendMail = $this->supUtilities->messageSendMail($row["FILIAL_LOGADA"], $assunto, $message, 'PORTAL E-COMMERCE');
            $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$row['CDFORNECED']]);

            if (isset($row["fileUpload"]) && sizeof($row["fileUpload"])) {
                $this->supUtilities->enviaEmail($row["EMAIL_LOGADO"], 'Comentário - ' . $infoComentario["NRPEDIDOCOL"], $emailFornecedor, $messageSendMail, $emailFornecedor, $row["DOCUMENTOANEXOFULLPATH"], $row["fileUpload"][0]["name"], $row["fileUpload"][0]["type"]);
            } else {
                $this->supUtilities->enviaEmail($row["EMAIL_LOGADO"], 'Comentário - ' . $infoComentario["NRPEDIDOCOL"], $emailFornecedor, $messageSendMail, $emailFornecedor);
            }
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 500));
        }
    }

    public function setFileFullPath(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();

        if ($row["DSIDDOCFILESERV"] !== null) {
            $row["DOCUMENTOANEXOFULLPATH"] = $this->fileServerURL . $row["DSIDDOCFILESERV"];
        }
        $dataset = array(
            "row"   => $row
        );
        $response->addDataSet(new DataSet('data', $dataset));
    }


    public function downloadFile(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getDataSet()->getRows()[0];
        $file = $row["DOCUMENTOANEXOFULLPATH"];
        $name = $row["DSDOCUMENTOANEXO"];
        $nameArray = explode(".", $name);
        $type = end($nameArray);
        header('Accept-Ranges: none');
        header("Content-Type: " . $type);
        header("Content-Disposition: attachment; filename=" . $name);
        readfile($file);
        exit;
    }

    public function incluirExcluirRegiao(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $errorRegioes = array();
        $errorMsg = "As seguintes regiões já existiam nos respectivos pedidos:<br>";
        $success = "<br>As demais regiões foram salvas com sucesso!";
        $errorMsgDel = "As seguintes regiões não foram encontradas nos respectivos pedidos:<br>";
        $successDel = "<br>As demais regiões foram excluídas com sucesso!";
        $regioesIncluidas = array();
        $regioesExcluidas = array();
        $errorRegioesSave = false;
        $errorRegioesDelete = false;

        try {
            $this->service->iniciaTransacao();
            foreach ($row['PEDIDOS'] as $pedido) {
                $pedido['EMAIL_LOGADO'] = $row['EMAIL_LOGADO'];
                $pedido['FILIAL_LOGADA'] = $row['FILIAL_LOGADA'];
                if ($row['OPERACAO'] === 'save') {
                    $this->service->incluirRegiao($pedido, $row['REGIAO'], $row['DTPEDCOLETA'], $errorRegioes, $regioesIncluidas);

                    if (!empty($regioesIncluidas)) {
                        $this->salvarComentarioRegiao($pedido, $row, $regioesIncluidas, $regioesExcluidas, $response);
                    } else {
                        $success = "";
                    }

                    if (!empty($errorRegioes)) {
                        foreach ($errorRegioes as $errorRegiao) {
                            $errorMsg .=  $errorRegiao['NRPEDIDOCOL'] . " - " . $errorRegiao['REGIAO'] . "<br>";
                        }
                        $errorRegioesSave = true;
                    } else {
                        $errorRegioesSave = false;
                        $msg = "Salvo com sucesso!";
                        $dataset = array(
                            "SUCCESSPEDIDOS"   => $msg
                        );
                    }
                } else {
                    $this->service->excluirRegiao($pedido, $row['REGIAO'], $errorRegioes, $regioesExcluidas);

                    if (!empty($regioesExcluidas)) {
                        $this->salvarComentarioRegiao($pedido, $row, $regioesIncluidas, $regioesExcluidas, $response);
                    } else {
                        $successDel = "";
                    }

                    if (!empty($errorRegioes)) {
                        foreach ($errorRegioes as $errorRegiao) {
                            $errorMsgDel .=  $errorRegiao['NRPEDIDOCOL'] . " - " . $errorRegiao['REGIAO'] . "<br>";
                        }
                        $errorRegioesDelete = true;
                    } else {
                        $errorRegioesDelete = false;
                        $msg = "Excluído com sucesso!";
                        $dataset = array(
                            "SUCCESSPEDIDOS"   => $msg
                        );
                    }
                }
            }
            if ($errorRegioesSave) {
                $errorMsg .= $success;
                $dataset = array(
                    "ERROPEDIDOS"   => $errorMsg
                );
            }
            if ($errorRegioesDelete) {
                $errorMsgDel .= $successDel;
                $dataset = array(
                    "ERROPEDIDOS"   => $errorMsgDel
                );
            }
            $response->addDataSet(new DataSet("data", $dataset));
            $this->service->commit();
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function getQuantidadeComprar(DTO\Request $request, DTO\Response $response)
    {
        try {
            $rows = $request->getDataSet()->getRows();

            $nrPedColeta = join("_", array_unique(array_map(function ($row) {
                return $row['NRPEDCOLETA'];
            }, $rows)));

            $nrPedidoCol = join("_", array_unique(array_map(function ($row) {
                return $row['NRPEDIDOCOL'];
            }, $rows)));

            $cdFilial = join("_", array_unique(array_map(function ($row) {
                return $row['CDFILIAL'];
            }, $rows)));

            $filter = array(
                array(
                    "columnName" => "P_CDFILIAL",
                    "value" => $cdFilial,
                    "operator" => "="
                ),
                array(
                    "columnName" => "P_NRPEDCOLETA",
                    "value" => $nrPedColeta,
                    "operator" => "="
                ),
                array(
                    "columnName" => "P_NRPEDIDOCOL",
                    "value" => $nrPedidoCol,
                    "operator" => "="
                )
            );

            $prodAComp = $this->crudService->getFilteredDataSet("qtdeAComp", $filter)->getRows();

            foreach ($prodAComp as $row) {
                $this->service->atualizaQtdeAComprar($row, $nrPedidoCol);
            }

            $response->addMessage(new DTO\Response\Message($prodAComp));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function getQuantidadeComprarMediaAF(DTO\Request $request, DTO\Response $response)
    {
        $rows = $request->getRow();

        try {

            $pedidos = $rows['PEDIDOS'];
            $consForne = $rows['IDCONSFORNAF'];
            $qtdMeses = $rows['QTMESES'];

            $nrPedColeta = join("_", array_unique(array_map(function ($row) {
                return $row['NRPEDCOLETA'];
            }, $pedidos)));

            $nrPedidoCol = join("_", array_unique(array_map(function ($row) {
                return $row['NRPEDIDOCOL'];
            }, $pedidos)));

            $cdFilial = join("_", array_unique(array_map(function ($row) {
                return $row['CDFILIAL'];
            }, $pedidos)));

            if ($consForne === 'S') {
                $cdForneced = join("_", array_unique(array_map(function ($row) {
                    return $row['CDFORNECED'];
                }, $pedidos)));
            } else {
                $cdForneced = null;
            }

            $filter = array(
                array(
                    "columnName" => "P_CDFILIAL",
                    "value" => $cdFilial,
                    "operator" => "="
                ),
                array(
                    "columnName" => "P_NRPEDCOLETA",
                    "value" => $nrPedColeta,
                    "operator" => "="
                ),
                array(
                    "columnName" => "P_NRPEDIDOCOL",
                    "value" => $nrPedidoCol,
                    "operator" => "="
                ),
                array(
                    "columnName" => "P_QTMESES",
                    "value" => $qtdMeses,
                    "operator" => "="
                ),
                array(
                    "columnName" => "P_CDFORNECED",
                    "value" => $cdForneced,
                    "operator" => "="
                )
            );

            $prodAComp = $this->crudService->getFilteredDataSet("qtdeACompAF", $filter)->getRows();

            foreach ($prodAComp as $row) {
                $this->service->atualizaQtdeAComprar($row, $row['NRPEDIDOCOL']);
            }
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function salvarComentarioRegiao($pedido, $row, $regioesIncluidas, $regioesExcluidas, $response)
    {
        try {
            $tag = "<br>";
            $count = 0;
            if ($row['OPERACAO'] === 'save' && !empty($regioesIncluidas)) {
                $msgRegiao = "Foram incluídas as seguintes regiões no pedido " . $pedido["NRPEDIDOCOL"] . ": <br>";
                $length = count($regioesIncluidas);
                foreach ($regioesIncluidas as $regiaoIncluida) {
                    if ($count === ($length - 1)) {
                        $tag = '';
                    }
                    $msgRegiao .= $regiaoIncluida["CDREGIAO"]  . " - " . $regiaoIncluida["NMREGIAO"] . $tag;
                    $count++;
                }
            } else if (!empty($regioesExcluidas)) {
                $msgRegiao = "Foram excluídas as seguintes regiões no pedido " . $pedido["NRPEDIDOCOL"] . ": <br>";
                $length = count($regioesExcluidas);
                $count = 0;
                foreach ($regioesExcluidas as $regiaoExcluida) {
                    if ($count === ($length - 1)) {
                        $tag = '';
                    }
                    $msgRegiao .= $regiaoExcluida["CDREGIAO"]  . " - " . $regiaoExcluida["NMREGIAO"] . $tag;
                    $count++;
                }
            }

            $pedido['TXCOMENTARIO'] = $msgRegiao;
            $pedido['TXEMAIL'] = $msgRegiao;
            $this->service->salvarComentario($pedido, true);
            $infoComentario  = $this->service->infoComentario($pedido);
            $this->enviaEmailComentarioRegiao($infoComentario, $pedido, $response);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function enviaEmailComentarioRegiao($infoComentario, $row, $response)
    {
        try {

            $assunto = 'Comentário - ' . $infoComentario["NRPEDIDOCOL"];
            $message = $this->service->getMessageIncluirExcluirRegião($infoComentario, $row['TXEMAIL']);
            $messageSendMail = $this->supUtilities->messageSendMail($row['FILIAL_LOGADA'], $assunto, $message, 'PORTAL E-COMMERCE');
            $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$row['CDFORNECED']]);

            $this->supUtilities->enviaEmail($row["EMAIL_LOGADO"], $assunto, $emailFornecedor, $messageSendMail, $emailFornecedor);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 500));
        }
    }

    public function liberarInconsistencias(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $pedidosInconsistentes = array();
        $pedidosGeraCot = array();
        $dataset = array();

        try {
            $this->service->iniciaTransacao();

            foreach ($row['PEDIDOS'] as $pedido) {
                $code = $this->service->ACEITA_PEDCOTWEB($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL'], 'S');

                if ($code['P_IDACEITEOK'] === 'OK') {
                    $pedido['EMAIL_LOGADO'] = $row['EMAIL_LOGADO'];
                    $pedido['FILIAL_LOGADA'] = $row['FILIAL_LOGADA'];
                    $pedidoAceito = $this->service->alteraStatus($pedido, 'liberarInconsistencia');
                    $this->salvarComentarioInconsistencia($pedido);
                    $infoComentario  = $this->service->infoComentario($pedido);
                    $this->enviaEmailComentario($infoComentario, $pedido, $response, 'liberarInconsistencia');
                    if ($pedidoAceito) {
                        $pedidosGeraCot[] = $pedido['NRPEDIDOCOL'];
                    }
                } else {
                    array_push($pedidosInconsistentes, array("NRPEDIDOCOL" => $pedido['NRPEDIDOCOL'], "INSCRICAO" => $pedido["CDFORNECED"], "FORNECEDOR" => $pedido["FORNECEDOR"]));
                }
            }

            if (!empty($pedidosInconsistentes)) {
                $params = "";

                foreach ($pedidosInconsistentes as $pedidoInconsistente) {
                    $params .= "<tr><td class='testOnError'>" . $pedidoInconsistente['NRPEDIDOCOL'] . "</td><td class='testOnError'>" . $pedidoInconsistente['INSCRICAO'] . "</td><td class='testOnError'>" . $pedido["FORNECEDOR"] . "</td>";
                }
                $dataset['PEDIDOSINCONSISTENTES'] = true;
                $dataset['CODE'] = 'PEDIDOS_AINDA_INCONSIST';
                $dataset['PARAM'] = $params;
            } else {
                $dataset['SUCCESSPEDIDOS'] = true;
                $dataset['CODE'] = 'INCONSIST_LIBERADAS';
            }
            if (!empty($pedidosGeraCot)) {
                $dataset['GERACOTACAO'] = $pedidosGeraCot;
            }

            $response->addDataSet(new DataSet("data", $dataset));

            $this->service->commit();
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function salvarComentarioInconsistencia($pedido)
    {
        $msgComentario = "As inconsistências do pedido " . $pedido["NRPEDIDOCOL"] . " foram liberadas. Gentileza aceitar novamente o pedido.";
        $pedido['TXCOMENTARIO'] = $msgComentario;
        $this->service->salvarComentario($pedido, false);
    }

    public function verificaInconsistencia(DTO\Request $request, DTO\Response $response)
    {
        try {
            $params = $request->getRow();
            $code = $this->service->ACEITA_PEDCOTWEB($params['CDFILIAL'], $params['NRPEDIDOCOL'], $params['IDCONSISTE']);
            $response->addDataSet(new DataSet('idaceiteok', array($code['P_IDACEITEOK'])));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function excluirProdutos(DTO\Request $request, DTO\Response $response)
    {
        $produtos = $request->getRow();
        $montaMensagem = 'Os seguintes produtos foram removidos do pedido ' . $produtos['PRODUTOS'][0]['NRPEDIDOCOL'] . ': ';
        try {
            $this->service->iniciaTransacao();

            foreach ($produtos['PRODUTOS'] as $produto) {
                $this->service->excluirProdutos($produto);
                $montaMensagem .= $produto['CDARVPRODFORMAT'] . ' - ' . $produto['NMPRODUTO'] . ' da marca ' . $produto['CDMARCA'] . ' - ' . $produto['NMMARCA'] . ', ';
            }
            $msgComentario = substr($montaMensagem, 0, -2) . '.';
            $row['TXCOMENTARIO'] = $msgComentario;
            $row['CDFILIAL'] = $produtos['PRODUTOS'][0]['CDFILIAL'];
            $row['NRPEDIDOCOL'] = $produtos['PRODUTOS'][0]['NRPEDIDOCOL'];
            $this->service->salvarComentario($row, false);
            $this->service->flush();
            $this->service->commit();
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function getIdSisDos(DTO\Request $request, DTO\Response $response)
    {
        try {
            $idSisDos = $this->service->getIdSisDos();
            $dataset = array(
                "IDSISDOS"   => $idSisDos
            );
            $response->addDataSet(new DataSet('data', $dataset));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function verifyRegionsFromOrder(DTO\Request $request, DTO\Response $response)
    {
        try {
            $rows = $request->getRow();
            $returnArray = [];

            foreach ($rows as $i => $row) {
                if (isset($row["NRPEDIDOCOL"])) {
                    $dataset = $this->service->verifyRegionsFromOrder($row);
                    $returnArray[$row["NRPEDIDOCOL"]] = $dataset["NUMREGIOES"];
                }
            }
            $response->addDataSet(new DataSet('regions', $returnArray));
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function insertMarcPedCol(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $this->service->insertMarcPedCol($row);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function insertItemPedCol(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $this->service->insertItemPedCol($row);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function insertComentPedCol(DTO\Request $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();
            $result = $this->service->insertComentPedCol($row);
            $this->service->enviaEmailComentario($result, $row, $response);
        } catch (\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function alterarDataValidade(DTO\Request $request, DTO\Response $response)
    {
        try {
            $this->service->iniciaTransacao();

            $row = $request->getRow();

            $cdfilial = '';
            $nrpedido = '';

            foreach ($row['PEDIDOS'] as $pedido) {
                $cdfilial .= $pedido['FILIAL'] . "_";
                $nrpedido .= $pedido['PEDIDO'] . "_";
            }

            $this->service->atualizaDataValidadePedcolgeral($nrpedido, $cdfilial, $row['DTINICIAL'], $row['DTFINAL']);
            $this->service->atualizaDataValidadePedcoleta($nrpedido, $row['DTINICIAL'], $row['DTFINAL']);

            $this->service->commit();
        } catch (\Exception $e) {
            $this->service->rollback();
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function dadosErroPedCot(DTO\Request\Filter  $request, DTO\Response $response)
    {

        $onDemandFilter = $request->getFilterCriteria();
        $conditions = $onDemandFilter->getConditions();

        $mensagens = $conditions[2];

        $onDemandFilter->setDataSourceName('logngerapedcol');

        $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($onDemandFilter, array());
        $dataSource = $this->dataSourceManager->findBy($newFilterCriteria);

        $dataSet = self::montaDataSet($dataSource->getRows(), $mensagens);
        $response->addDataSet(new DataSet('data', $dataSet));
    }

    public function montaDataSet(array $dataSource, $mensagens)
    {
        $dataSet = array();

        foreach ($dataSource as $data) {
            //tratar aqui
            $pieces = str_split($data['IDMOTNGERPEDCOL']);
            for ($i = 0; $i < count($pieces); $i++) {

                if ($pieces[$i] == '1') {
                    switch ($i) {
                        case 0:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][0];
                            break;

                        case 1:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][1];
                            break;
                        case 2:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][2];
                            break;

                        case 3:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][3];
                            break;

                        case 4:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][4];
                            break;

                        case 5:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][5];
                            break;
                        case 6:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][6];
                            break;
                        case 7:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][7];
                            break;
                        case 8:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][8];
                            break;

                        case 9:
                            $data['IDMOTNGERPEDCOL'] = $mensagens['value'][9];
                            break;

                        default:
                            break;
                    }

                    array_push($dataSet, array(
                        'NMFANTFORN'        => $data['NMFANTFORN'],
                        'NRINSJURFORN'      => $data['NRINSJURFORN'],
                        'NMREGIAO'          => $data['NMREGIAO'],
                        'CDREGIAO'          => $data['CDREGIAO'],
                        'REGIAO'            => $data['REGIAO'],
                        'FORNECEDOR'        => $data['FORNECEDOR'],
                        'PEDIDO'            => $data['PEDIDO'],
                        'PRODUTO'           => $data['PRODUTO'],
                        'IDMOTNGERPEDCOL'   => $data['IDMOTNGERPEDCOL']
                    ));
                }
            }
        }

        return $dataSet;
    }

    public function retornaLista(DTO\Request $request, DTO\Response $response)
    {
        $rows = $request->getDataSet()->getRows();
        $newData = array();
        foreach ($rows as $row) {
            $dados = $this->service->selectlista($row);
            if ($dados) {
                array_push($newData, $dados);
            }
        }
        $response->addDataSet(new DataSet('data', $newData));
    }

    private function pushResultArray($row, $data, $result, $error)
    {
        $resultArray = array(
            'CDFORNECED'   => $row['CDFORNECED'],
            'IDTPIJURFORN' => $row['IDTPIJURFORN'],
            'NRINSJURFORN' => $row['NRINSJURFORN'],
            'NMFANTFORN'   => $row['NMFANTFORN'],
            'NMRAZSOCFORN' => $row['NMRAZSOCFORN'],
            'RESULT'       => $result,
            'ERROR'        => $error
        );

        array_push($data, $resultArray);

        return $data;
    }

    public function sendDeleteMail(DTO\Request $request, DTO\Response $response)
    {
        $data = $request->getRow();
        $result = array();

        try {
            if (isset($data['FORNECEDOR'])) {
                $row = $data['FORNECEDOR'];
                try {
                    $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$row['CDFORNECED']]);

                    try {
                        $messageSendMail = $this->supUtilities->messageSendMail($this->service->getCdFilial(), $data['ASSUNTO'], $data['MENSAGEM'], 'PORTAL E-COMMERCE');
                        $this->supUtilities->enviaEmail($data['EMAIL'], $data['ASSUNTO'], $data['EMAIL'], $messageSendMail, $emailFornecedor);
                        $result = $this->pushResultArray($row, $result, 'SUCCESS', null);
                    } catch (\Exception $e) {
                        $result = $this->pushResultArray($row, $result, 'ERROR', $e->getMessage());
                    }
                } catch (\Exception $e) {
                    $result = $this->pushResultArray($row, $result, 'ERROR', $e->getMessage());
                }
            }

            $response->addDataSet(new DataSet('data', $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function sendEmailSupplier(DTO\Request $request, DTO\Response $response)
    {
        $data = $request->getRow();
        $result = array();

        try {

            if (isset($data['SUPPLIER'])) {
                $row = $data['SUPPLIER'];
                try {
                    $emailFornecedor = $this->supUtilities->retornarEmailsRelacionadosFornecedor([$row['CDFORNECED']]);

                    try {
                        $messageSendMail = $this->supUtilities->messageSendMail($this->service->getCdFilial(), $data['SUBJECT'], $data['BODY'], 'PORTAL E-COMMERCE');
                        $this->supUtilities->enviaEmail($data['EMAIL'], $data['SUBJECT'], $data['EMAIL'], $messageSendMail, $emailFornecedor);
                        $result = $this->pushResultArray($row, $result, 'SUCCESS', null);
                    } catch (\Exception $e) {
                        $result = $this->pushResultArray($row, $result, 'ERROR', $e->getMessage());
                    }
                } catch (\Exception $e) {
                    $result = $this->pushResultArray($row, $result, 'ERROR', $e->getMessage());
                }
            }

            $response->addDataSet(new DataSet('data', $result));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function deletaPedido(DTO\Request $request, DTO\Response $response)
    {
        $row = $request->getRow();
        $pedidos = $row['PEDIDOS'];
        $comment = $row['COMMENT'];
        $pedidosExcluidos = [];
        try {
            $this->service->iniciaTransacao();

            foreach ($pedidos as &$pedido) {
                if (($pedido['IDSITUPEDCOLETA'] == 'NR' || $pedido['IDSITUPEDCOLETA'] == 'NN') && $pedido['EXISTS_ITEMCOLE'] == 'N') {

                    $this->service->deletaPedcoleta($pedido['CDFILIAL'], $pedido['NRPEDCOLETA'], $pedido['CDFORNECED'], $pedido['CDREGIAO']);
                    $this->service->deletaItempedcol($pedido['CDFILIAL'], $pedido['NRPEDCOLETA'], $pedido['CDFORNECED'], $pedido['CDREGIAO']);
                    $this->service->deletaRegiaopedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL'], $pedido['CDREGIAO']);
                    $this->service->deletaPrmarcpedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL'], $pedido['CDFORNECED']);
                    $this->service->deletaFornepedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL'], $pedido['CDFORNECED']);

                    array_push($pedidosExcluidos, [
                        'IDTPIJURFORN' => $pedido['IDTPIJURFORN'],
                        'NRINSJURFORN' => $pedido['NRINSJURFORN'],
                        'NMFANTFORN'   => $pedido['NMFANTFORN'],
                        'NMRAZSOCFORN' => $pedido['NMRAZSOCFORN'],
                        'NRPEDIDOCOL'  => $pedido['NRPEDIDOCOL'],
                        'NRPEDCOLETA'  => $pedido['NRPEDCOLETA'],
                        'CDREGIAO'     => $pedido['CDREGIAO'],
                        'NMREGIAO'     => $pedido['NMREGIAO'],
                        'CDFORNECED'   => $pedido['CDFORNECED'],
                        'CDFILIAL'     => $pedido['CDFILIAL']
                    ]);
                }
            }
            $standartMsg = $this->service->selectMsgEnvEmail('X');
            $urlPortal = $this->service->getURLPortal();

            $data['READONLY'] = isset($standartMsg['DSBODY']);
            $data['DSSUBJECT'] = isset($standartMsg['DSSUBJECT']) ? $standartMsg['DSSUBJECT'] : '';
            $data['DSBODY'] = isset($standartMsg['DSBODY']) ? $standartMsg['DSBODY'] : '';
            $data['URL'] = $urlPortal;

            foreach ($pedidosExcluidos as &$pedido) {
                $pedido['NOTEXISTSPED'] = $this->service->notExistsPedcoleta($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL']);
                if ($pedido['NOTEXISTSPED']) {
                    $this->service->deletaLogacespedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL']);
                    $this->service->deletaComentpedcol($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL']);
                    $this->service->deletaPedcolgeral($pedido['CDFILIAL'], $pedido['NRPEDIDOCOL']);
                }
                $pedido['COMMENT'] = str_replace('__CDREGIAO__', $pedido['CDREGIAO'] . ' - ' . $pedido['NMREGIAO'], $comment);
                $pedido['COMMENT'] = str_replace('__NRPEDIDOCOL__', $pedido['NRPEDIDOCOL'], $pedido['COMMENT']);
            }

            $this->service->saveComments($pedidosExcluidos);

            $this->service->commit();
            $response->addDataSet(new DataSet('data', ['PEDIDOS' => $pedidosExcluidos, 'DATA' => $data]));
        } catch (Exception $e) {
            $this->service->rollback();
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function getMensagemEnvioEmail(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $row = $request->getRow();

            /*$aux = false;
            if($row["OPERACAO"] == 'ALTERAR_VALIDADE'){
                $idoperacao = 'V';
                $aux = true;
            }
            if($row["OPERACAO"] == 'ALTERAR_EXPIRACAO'){
                $idoperacao = 'E';
                $aux = true;
            }
            if($row["OPERACAO"] == 'RETORNAR'){
                $idoperacao = 'N';
                $aux = true;
            }*/
            $standartMsg = $this->service->selectMsgEnvEmail($row['IDOPERACAO']);

            $data['READONLY'] = isset($standartMsg['DSBODY']);
            $data['DSSUBJECT'] = isset($standartMsg['DSSUBJECT']) ? $standartMsg['DSSUBJECT'] : '';
            $data['DSBODY'] = isset($standartMsg['DSBODY']) ? $standartMsg['DSBODY'] : '';
            $data['URL_PORTAL'] = $this->service->getURLPortal();

            $response->addDataSet(new DataSet('data', $data));
        } catch (Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
